SFCertificatePanel

Struct SFCertificatePanel 

pub struct SFCertificatePanel { /* private fields */ }
Available on crate feature SFCertificatePanel only.
SFCertificatePanel is a panel and sheet interface that displays one or more certificates.

See also Apple’s documentation

Implementations

Source

impl SFCertificatePanel

pub unsafe fn sharedCertificatePanel( mtm: MainThreadMarker, ) -> Option<Retained<SFCertificatePanel>>

Returns a shared instance of SFCertificatePanel.

If your application can display multiple SFCertificatePanels at once, you should allocate (alloc) and initialize (init) separate object instances instead of using this class method.

pub unsafe fn runModalForTrust_showGroup( &self, trust: Option<&SecTrust>, show_group: bool, ) -> NSInteger

Available on crate feature objc2-security only.

Displays a certificate chain in a modal panel, returning NSOKButton when dismissed. This method is preferred over runModalForCertificates, since the SecTrustRef parameter lets you specify policies that determine whether the certificate is valid within your application’s context.

Parameter trust: A trust reference which contains the certificates to display.

Parameter showGroup: Specifies whether additional certificates (other than the leaf certificate) are displayed.

Safety

trust might not allow None.

pub unsafe fn runModalForCertificates_showGroup( &self, certificates: Option<&NSArray>, show_group: bool, ) -> NSInteger

Displays one or more specified certificates in a modal panel, returning NSOKButton when dismissed.

Parameter certificates: The certificates to display. Pass a NSArray containing one or more SecCertificateRef instances in this parameter. The leaf certificate is assumed to be at index 0; the order of additional certificates in the array is not critical.

Parameter showGroup: Specifies whether additional certificates (other than the leaf certificate) are displayed. To show only a single certificate, specify only one SecCertificateRef in the array and set showGroup to NO.

Safety
  • certificates generic should be of the correct type.
  • certificates might not allow None.
pub unsafe fn beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_trust_showGroup( &self, doc_window: Option<&NSWindow>, delegate: Option<&AnyObject>, did_end_selector: Option<Sel>, context_info: *mut c_void, trust: Option<&SecTrust>, show_group: bool, )

Available on crate feature objc2-security only.

Displays a certificate chain in a modal sheet. This is the preferred sheet method for SFCertificatePanel, since the SecTrustRef parameter lets you specify policies that determine whether the certificate is valid within your application’s context.

Parameter docWindow: The parent window to which the sheet is attached.

Parameter modalDelegate: The object whose didEndSelector method will be called when the sheet is dismissed.

Parameter didEndSelector: This method is called when the sheet is dismissed.

Parameter contextInfo: Client-defined contextual data which will be passed to the didEndSelector method.

Parameter trust: A trust reference which contains the certificates to display.

Parameter showGroup: Specifies whether additional certificates (other than the leaf certificate) are displayed.

The didEndSelector method should have the following signature:

  • (void)certificateSheetDidEnd:(NSWindow *)sheet returnCode:(NSInteger)returnCode contextInfo:(void *)contextInfo
Safety
  • doc_window might not allow None.
  • delegate should be of the correct type.
  • delegate might not allow None.
  • did_end_selector must be a valid selector.
  • context_info must be a valid pointer.
  • trust might not allow None.
pub unsafe fn beginSheetForWindow_modalDelegate_didEndSelector_contextInfo_certificates_showGroup( &self, doc_window: Option<&NSWindow>, delegate: Option<&AnyObject>, did_end_selector: Option<Sel>, context_info: *mut c_void, certificates: Option<&NSArray>, show_group: bool, )

Displays one or more specified certificates in a modal sheet.

Parameter docWindow: The parent window to which the sheet is attached.

Parameter modalDelegate: The object whose didEndSelector method will be called when the sheet is dismissed.

Parameter didEndSelector: This method is called when the sheet is dismissed.

Parameter contextInfo: Client-defined contextual data which will be passed to the didEndSelector method.

Parameter certificates: The certificates to display. Pass a NSArray containing one or more SecCertificateRef instances in this parameter.

Parameter showGroup: Specifies whether additional certificates (other than the leaf certificate) are displayed.

The didEndSelector method should have the following signature:

  • (void)certificateSheetDidEnd:(NSWindow *)sheet returnCode:(NSInteger)returnCode contextInfo:(void *)contextInfo
Safety
  • doc_window might not allow None.
  • delegate should be of the correct type.
  • delegate might not allow None.
  • did_end_selector must be a valid selector.
  • context_info must be a valid pointer.
  • certificates generic should be of the correct type.
  • certificates might not allow None.
pub unsafe fn setPolicies(&self, policies: Option<&AnyObject>)

Specifies one or more policies that apply to the displayed certificates.

Parameter policies: The policies to use when evaluating the certificates’ status. You can pass either a SecPolicyRef or a NSArray (containing one or more SecPolicyRef instances) in this parameter. If policies is set to nil, the Apple X.509 Basic Policy will be used.

Applications will typically display a SFCertificatePanel in the context of a specific usage, such as SSL or S/MIME. You should set only the policy references which apply to your intended usage.

Safety
  • policies should be of the correct type.
  • policies might not allow None.
pub unsafe fn policies(&self) -> Option<Retained<NSArray>>

Returns an array of policies used to evaluate the status of the displayed certificates.

This method returns an autoreleased NSArray containing one or more SecPolicyRef instances, as set by a previous setPolicies: call.

pub unsafe fn setDefaultButtonTitle(&self, title: Option<&NSString>)

Customizes the title of the default button.

Parameter title: The new title for the default button.

Safety

title might not allow None.

pub unsafe fn setAlternateButtonTitle(&self, title: Option<&NSString>)

Customizes the title of the alternate button.

Parameter title: The new title for the alternate button. If title is set to nil, the button will not be shown.

Safety

title might not allow None.

pub unsafe fn setShowsHelp(&self, shows_help: bool)

pub unsafe fn showsHelp(&self) -> bool

pub unsafe fn setHelpAnchor(&self, anchor: Option<&NSString>)

Safety

anchor might not allow None.

pub unsafe fn helpAnchor(&self) -> Option<Retained<NSString>>

pub unsafe fn certificateView(&self) -> Option<Retained<SFCertificateView>>

Available on crate feature SFCertificateView only.
Source

impl SFCertificatePanel

Methods declared on superclass NSWindow.

pub unsafe fn initWithContentRect_styleMask_backing_defer( this: Allocated<Self>, content_rect: NSRect, style: NSWindowStyleMask, backing_store_type: NSBackingStoreType, flag: bool, ) -> Retained<Self>

pub unsafe fn initWithContentRect_styleMask_backing_defer_screen( this: Allocated<Self>, content_rect: NSRect, style: NSWindowStyleMask, backing_store_type: NSBackingStoreType, flag: bool, screen: Option<&NSScreen>, ) -> Retained<Self>

pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Retained<Self>

Safety

coder possibly has further requirements.

pub unsafe fn windowWithContentViewController( content_view_controller: &NSViewController, ) -> Retained<Self>

Convenience method for creating an autoreleased titled window with the given contentViewController. A basic NSWindow with the following attributes is made: titled, closable, resizable, miniaturizable. The window’s title is automatically bound to the contentViewController’s title. The size of the window can easily be controlled by utilizing autolayout and applying size constraints to the view (or its subviews). The window has isReleasedWhenClosed set to NO, and it must be explicitly retained to keep the window instance alive. To have it automatically be freed when it is closed, do the following: [window retain] and [window setReleasedWhenClosed:YES].

Source

impl SFCertificatePanel

Methods declared on superclass NSResponder.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl SFCertificatePanel

Methods declared on superclass NSObject.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = NSPanel>

pub fn isFloatingPanel(&self) -> bool

Available on crate features NSResponder and NSWindow only.
pub fn setFloatingPanel(&self, floating_panel: bool)

Available on crate features NSResponder and NSWindow only.

Setter for isFloatingPanel.

pub fn becomesKeyOnlyIfNeeded(&self) -> bool

Available on crate features NSResponder and NSWindow only.
pub fn setBecomesKeyOnlyIfNeeded(&self, becomes_key_only_if_needed: bool)

Available on crate features NSResponder and NSWindow only.
pub fn worksWhenModal(&self) -> bool

Available on crate features NSResponder and NSWindow only.
pub fn setWorksWhenModal(&self, works_when_modal: bool)

Available on crate features NSResponder and NSWindow only.

Setter for worksWhenModal.

Methods from Deref<Target = NSWindow>

pub fn frameRectForContentRect(&self, content_rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn contentRectForFrameRect(&self, frame_rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn title(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn setTitle(&self, title: &NSString)

Available on crate feature NSResponder only.

Setter for title.

This is copied when set.

pub fn subtitle(&self) -> Retained<NSString>

Available on crate feature NSResponder only.

Secondary text that may be displayed adjacent to or below the primary title depending on the configuration of the window. A value of empty string will remove the subtitle from the window layout.

pub fn setSubtitle(&self, subtitle: &NSString)

Available on crate feature NSResponder only.

Setter for subtitle.

This is copied when set.

pub fn titleVisibility(&self) -> NSWindowTitleVisibility

Available on crate feature NSResponder only.

See the enum values for how this property works.

pub fn setTitleVisibility(&self, title_visibility: NSWindowTitleVisibility)

Available on crate feature NSResponder only.

Setter for titleVisibility.

pub fn titlebarAppearsTransparent(&self) -> bool

Available on crate feature NSResponder only.

When YES,the titlebar doesn’t draw its background, allowing all buttons to show through, and “click through” to happen. In general, this is only useful when NSFullSizeContentViewWindowMaskis set.

pub fn setTitlebarAppearsTransparent(&self, titlebar_appears_transparent: bool)

Available on crate feature NSResponder only.
pub fn toolbarStyle(&self) -> NSWindowToolbarStyle

Available on crate feature NSResponder only.

Specifies how the titlebar area of the window should appear when the window displays an NSToolbar

pub fn setToolbarStyle(&self, toolbar_style: NSWindowToolbarStyle)

Available on crate feature NSResponder only.

Setter for toolbarStyle.

pub fn contentLayoutRect(&self) -> CGRect

Available on crate feature NSResponder only.

The contentLayoutRectwill return the area inside the window that is for non-obscured content. Typically, this is the same thing as the contentView’s frame. However, for windows with the NSFullSizeContentViewWindowMaskset, there needs to be a way to determine the portion that is not under the toolbar. The contentLayoutRectreturns the portion of the layout that is not obscured under the toolbar. contentLayoutRectis in window coordinates. It is KVO compliant. */

pub fn contentLayoutGuide(&self) -> Option<Retained<AnyObject>>

Available on crate feature NSResponder only.

contentLayoutGuideis a corollary to contentLayoutRect.It can be used by autolayout constraints to automatically bind to the contentLayoutRect.

pub fn removeTitlebarAccessoryViewControllerAtIndex(&self, index: isize)

Available on crate feature NSResponder only.
pub fn representedURL(&self) -> Option<Retained<NSURL>>

Available on crate feature NSResponder only.

If url is not nil and its path is not empty, the window will show a document icon in the titlebar. If the url represents a filename or other resource with a known icon, that icon will be used as the document icon. Otherwise the default document icon will be used. The icon can be customized using -[[NSWindow standardWindowButton:NSWindowDocumentIconButton] setImage:customImage]. If url is not nil and its path is not empty, the window will have a pop-up menu which can be shown via command-click on the area containing the document icon and title. By default, this menu will display the path components of the url. The presence and contents of this menu can be controlled by the delegate method -[window:shouldPopUpDocumentPathMenu:] If the url is nil or has an empty path, the window will not show a document icon and will not have a pop-up menu available via command-click.

pub fn setRepresentedURL(&self, represented_url: Option<&NSURL>)

Available on crate feature NSResponder only.

Setter for representedURL.

This is copied when set.

pub fn representedFilename(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn setRepresentedFilename(&self, represented_filename: &NSString)

Available on crate feature NSResponder only.

Setter for representedFilename.

This is copied when set.

pub fn setTitleWithRepresentedFilename(&self, filename: &NSString)

Available on crate feature NSResponder only.
pub fn isExcludedFromWindowsMenu(&self) -> bool

Available on crate feature NSResponder only.
pub fn setExcludedFromWindowsMenu(&self, excluded_from_windows_menu: bool)

Available on crate feature NSResponder only.
pub fn contentView(&self) -> Option<Retained<NSView>>

Available on crate features NSResponder and NSView only.
pub fn setContentView(&self, content_view: Option<&NSView>)

Available on crate features NSResponder and NSView only.

Setter for contentView.

pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn NSWindowDelegate>>>

Available on crate feature NSResponder only.
pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn NSWindowDelegate>>, )

Available on crate feature NSResponder only.

Setter for delegate.

This is a weak property.

pub fn windowNumber(&self) -> isize

Available on crate feature NSResponder only.
pub fn styleMask(&self) -> NSWindowStyleMask

Available on crate feature NSResponder only.

Note: The styleMask can only be set on macOS 10.6 and later. Valid styleMasksettings have the same restrictions as the styleMaskpassed to -initWithContentRect:styleMask:backing:defer:. Some styleMaskchanges will cause the view hierarchy to be rebuilt, since there is a different subclass for the top level view of a borderless window than for the top level view of a titled window.

pub fn setStyleMask(&self, style_mask: NSWindowStyleMask)

Available on crate feature NSResponder only.

Setter for styleMask.

pub unsafe fn endEditingFor(&self, object: Option<&AnyObject>)

Available on crate feature NSResponder only.
Safety

object should be of the correct type.

pub fn constrainFrameRect_toScreen( &self, frame_rect: CGRect, screen: Option<&NSScreen>, ) -> CGRect

Available on crate features NSResponder and NSScreen only.
pub fn setFrame_display(&self, frame_rect: CGRect, flag: bool)

Available on crate feature NSResponder only.
pub fn setContentSize(&self, size: CGSize)

Available on crate feature NSResponder only.
pub fn setFrameOrigin(&self, point: CGPoint)

Available on crate feature NSResponder only.
pub fn setFrameTopLeftPoint(&self, point: CGPoint)

Available on crate feature NSResponder only.
pub fn cascadeTopLeftFromPoint(&self, top_left_point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn cascadingReferenceFrame(&self) -> CGRect

Available on crate feature NSResponder only.

The frame to use when cascading or sizing a new window based on the receiver’s position or size. This may be different from frame when the receiver is positioned by the system.

pub fn frame(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn animationResizeTime(&self, new_frame: CGRect) -> f64

Available on crate feature NSResponder only.

Subclasses can override animationResizeTime:to control the total time for the frame change. newFrameis the rect passed into setFrame:display:animate:

pub fn setFrame_display_animate( &self, frame_rect: CGRect, display_flag: bool, animate_flag: bool, )

Available on crate feature NSResponder only.

setFrame:display:animate:is equivalent to setFrame:display:if the animateFlagis NO. If the animationFlagis YES, this method will perform a smooth resize of the window, where the total time for the resize is specified by -animationResizeTime:

pub fn inLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn resizeIncrements(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setResizeIncrements(&self, resize_increments: CGSize)

Available on crate feature NSResponder only.

Setter for resizeIncrements.

pub fn aspectRatio(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setAspectRatio(&self, aspect_ratio: CGSize)

Available on crate feature NSResponder only.

Setter for aspectRatio.

pub fn contentResizeIncrements(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setContentResizeIncrements(&self, content_resize_increments: CGSize)

Available on crate feature NSResponder only.
pub fn contentAspectRatio(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setContentAspectRatio(&self, content_aspect_ratio: CGSize)

Available on crate feature NSResponder only.

Setter for contentAspectRatio.

pub fn viewsNeedDisplay(&self) -> bool

Available on crate feature NSResponder only.
pub fn setViewsNeedDisplay(&self, views_need_display: bool)

Available on crate feature NSResponder only.

Setter for viewsNeedDisplay.

pub fn displayIfNeeded(&self)

Available on crate feature NSResponder only.
pub fn display(&self)

Available on crate feature NSResponder only.
pub fn preservesContentDuringLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPreservesContentDuringLiveResize( &self, preserves_content_during_live_resize: bool, )

Available on crate feature NSResponder only.
pub fn update(&self)

Available on crate feature NSResponder only.
pub fn makeFirstResponder(&self, responder: Option<&NSResponder>) -> bool

Available on crate feature NSResponder only.
pub fn firstResponder(&self) -> Option<Retained<NSResponder>>

Available on crate feature NSResponder only.
pub fn close(&self)

Available on crate feature NSResponder only.
pub fn isReleasedWhenClosed(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setReleasedWhenClosed(&self, released_when_closed: bool)

Available on crate feature NSResponder only.
pub fn miniaturize(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn deminiaturize(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn isZoomed(&self) -> bool

Available on crate feature NSResponder only.
pub fn zoom(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn isMiniaturized(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool

Available on crate feature NSResponder only.
Safety
  • action must be a valid selector.
  • object should be of the correct type.
pub fn setAutorecalculatesContentBorderThickness_forEdge( &self, flag: bool, edge: NSRectEdge, )

Available on crate feature NSResponder only.
pub fn autorecalculatesContentBorderThicknessForEdge( &self, edge: NSRectEdge, ) -> bool

Available on crate feature NSResponder only.
pub fn isMovable(&self) -> bool

Available on crate feature NSResponder only.
pub fn setMovable(&self, movable: bool)

Available on crate feature NSResponder only.

Setter for isMovable.

pub fn isMovableByWindowBackground(&self) -> bool

Available on crate feature NSResponder only.
pub fn setMovableByWindowBackground(&self, movable_by_window_background: bool)

Available on crate feature NSResponder only.
pub fn hidesOnDeactivate(&self) -> bool

Available on crate feature NSResponder only.
pub fn setHidesOnDeactivate(&self, hides_on_deactivate: bool)

Available on crate feature NSResponder only.

Setter for hidesOnDeactivate.

pub fn canHide(&self) -> bool

Available on crate feature NSResponder only.

Indicates whether a window can be hidden during -[NSApplication hide:]. Default is YES.

pub fn setCanHide(&self, can_hide: bool)

Available on crate feature NSResponder only.

Setter for canHide.

pub fn center(&self)

Available on crate feature NSResponder only.
pub fn makeKeyAndOrderFront(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn orderFront(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn orderBack(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn orderOut(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn orderWindow_relativeTo( &self, place: NSWindowOrderingMode, other_win: isize, )

Available on crate features NSGraphics and NSResponder only.
pub fn orderFrontRegardless(&self)

Available on crate feature NSResponder only.
pub fn miniwindowTitle(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn setMiniwindowTitle(&self, miniwindow_title: Option<&NSString>)

Available on crate feature NSResponder only.

Setter for miniwindowTitle.

This is copied when set.

pub fn isDocumentEdited(&self) -> bool

Available on crate feature NSResponder only.
pub fn setDocumentEdited(&self, document_edited: bool)

Available on crate feature NSResponder only.

Setter for isDocumentEdited.

pub fn isVisible(&self) -> bool

Available on crate feature NSResponder only.
pub fn isKeyWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn isMainWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn canBecomeKeyWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn canBecomeMainWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn makeKeyWindow(&self)

Available on crate feature NSResponder only.

Makes the window key and main if eligible, updating NSApplication’s -keyWindow and -mainWindow properties.

pub fn makeMainWindow(&self)

Available on crate feature NSResponder only.

Makes the window main if eligible. Updates NSApplication’s -mainWindow property.

pub fn becomeKeyWindow(&self)

Available on crate feature NSResponder only.

Informs the window that it has become the key window. This method exists as an override point. Do not invoke directly. Instead, invoke -makeKeyWindow.

pub fn resignKeyWindow(&self)

Available on crate feature NSResponder only.

Informs the window that it has stopped being the key window. This method exists as an override point. Do not invoke directly. Windows automatically receive this message when deactivating or when another window has become key.

pub fn becomeMainWindow(&self)

Available on crate feature NSResponder only.

Informs the window that it has become the main window. This method exists as an override point. Do not invoke directly. Instead, invoke -makeMainWindow.

pub fn resignMainWindow(&self)

Available on crate feature NSResponder only.

Informs the window that it has stopped being the main window. This method exists as an override point. Do not invoke directly. Windows automatically receive this message when deactivating or when another window has become main.

pub fn worksWhenModal(&self) -> bool

Available on crate feature NSResponder only.
pub fn preventsApplicationTerminationWhenModal(&self) -> bool

Available on crate feature NSResponder only.

A Boolean value that indicates whether or not to prevent application termination when the receiving window is presented modally. The value of this property is YES if the window should prevent application termination when modal; otherwise, NO. The default value is YES. However, note that some window subclasses and some windows created indirectly (like those created by UI frameworks like AppKit and SwiftUI), may have different default values. For example, the Open panel and toolbar customization sheets should not prevent application termination, so those windows have preventsApplicationTerminationWhenModal set to NO. Some NSAlerts, like those that are simply informational, have windows that do not prevent application termination by default. Setting this property overrides the default behavior.

pub fn setPreventsApplicationTerminationWhenModal( &self, prevents_application_termination_when_modal: bool, )

Available on crate feature NSResponder only.
pub fn convertRectToScreen(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromScreen(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToScreen(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromScreen(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertRectToBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn backingAlignedRect_options( &self, rect: CGRect, options: NSAlignmentOptions, ) -> CGRect

Available on crate feature NSResponder only.

Use NSIntegralRectWithOptions() to produce a backing store pixel aligned rectangle from the given input rectangle in window coordinates.

pub fn performClose(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn performMiniaturize(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn performZoom(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn dataWithEPSInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub fn dataWithPDFInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub fn print(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn allowsToolTipsWhenApplicationIsInactive(&self) -> bool

Available on crate feature NSResponder only.

Default is NO.Set to YESto allow a window to display tooltips even when the application is in the background. Note that, enabling tooltips in an inactive application will cause the app to do work any time the mouse passes over the window. This can degrade system performance. Returns YESif this window displays tooltips even when the application is in the background. To configure this setting you should call -setAllowsToolTipsWhenApplicationIsInactive: instead of overriding -allowsToolTipsWhenApplicationIsInactive.

pub fn setAllowsToolTipsWhenApplicationIsInactive( &self, allows_tool_tips_when_application_is_inactive: bool, )

Available on crate feature NSResponder only.
pub fn backingType(&self) -> NSBackingStoreType

Available on crate features NSGraphics and NSResponder only.
pub fn setBackingType(&self, backing_type: NSBackingStoreType)

Available on crate features NSGraphics and NSResponder only.

Setter for backingType.

pub fn level(&self) -> isize

Available on crate feature NSResponder only.
pub fn setLevel(&self, level: isize)

Available on crate feature NSResponder only.

Setter for level.

pub fn depthLimit(&self) -> NSWindowDepth

Available on crate features NSGraphics and NSResponder only.
pub fn setDepthLimit(&self, depth_limit: NSWindowDepth)

Available on crate features NSGraphics and NSResponder only.

Setter for depthLimit.

pub fn setDynamicDepthLimit(&self, flag: bool)

Available on crate feature NSResponder only.
pub fn hasDynamicDepthLimit(&self) -> bool

Available on crate feature NSResponder only.
pub fn screen(&self) -> Option<Retained<NSScreen>>

Available on crate features NSResponder and NSScreen only.

The screen property returns the best screen for the window. If the window only intersects one screen, it returns that screen. If it intersects more than one screen, then it resolves the tie through based on what space it is mostly on. It may return nil if there are no available screens, or it is completely off screen.

pub fn deepestScreen(&self) -> Option<Retained<NSScreen>>

Available on crate features NSResponder and NSScreen only.
pub fn hasShadow(&self) -> bool

Available on crate feature NSResponder only.
pub fn setHasShadow(&self, has_shadow: bool)

Available on crate feature NSResponder only.

Setter for hasShadow.

pub fn invalidateShadow(&self)

Available on crate feature NSResponder only.
pub fn isOpaque(&self) -> bool

Available on crate feature NSResponder only.
pub fn setOpaque(&self, opaque: bool)

Available on crate feature NSResponder only.

Setter for isOpaque.

pub fn sharingType(&self) -> NSWindowSharingType

Available on crate feature NSResponder only.

-setSharingType: specifies whether the window content can be read from another process. The default sharing type is NSWindowSharingReadOnly,which means other processes can read the window content (eg. for window capture) but cannot modify it. If you set your window sharing type to NSWindowSharingNone,so that the content cannot be captured, your window will also not be able to participate in a number of system services, so this setting should be used with caution.

pub fn setSharingType(&self, sharing_type: NSWindowSharingType)

Available on crate feature NSResponder only.

Setter for sharingType.

pub fn allowsConcurrentViewDrawing(&self) -> bool

Available on crate feature NSResponder only.

Controls whether threading of view drawing should be enabled for this window. Defaults to YES.When this is set to YES,AppKit’s view system is allowed to perform -drawRect: activity for the window’s views on threads other than the main thread, for views that have canDrawConcurrently == YES. When this is set to NO,the window’s views will be drawn serially as on 10.5 and earlier, even though some of the views may have canDrawConcurrently == YES.

pub unsafe fn setAllowsConcurrentViewDrawing( &self, allows_concurrent_view_drawing: bool, )

Available on crate feature NSResponder only.
pub fn displaysWhenScreenProfileChanges(&self) -> bool

Available on crate feature NSResponder only.
pub fn setDisplaysWhenScreenProfileChanges( &self, displays_when_screen_profile_changes: bool, )

Available on crate feature NSResponder only.
pub fn canBecomeVisibleWithoutLogin(&self) -> bool

Available on crate feature NSResponder only.

This API controls whether the receiver is permitted onscreen before the user has logged in. This property is off by default. Alert panels and windows presented by input managers are examples of windows which should have this property set.

pub fn setCanBecomeVisibleWithoutLogin( &self, can_become_visible_without_login: bool, )

Available on crate feature NSResponder only.
pub fn collectionBehavior(&self) -> NSWindowCollectionBehavior

Available on crate feature NSResponder only.
pub fn setCollectionBehavior( &self, collection_behavior: NSWindowCollectionBehavior, )

Available on crate feature NSResponder only.

Setter for collectionBehavior.

pub fn animationBehavior(&self) -> NSWindowAnimationBehavior

Available on crate feature NSResponder only.

Provides for per-window control over automatic orderFront/orderOut animation behaviors added in 10.7. Can be set to NSWindowAnimationBehaviorNoneto disable Appkit’s automatic animations for a given window, or to one of the other non-Default NSWindowAnimationBehaviorvalues to override AppKit’s automatic inference of appropriate animation behavior based on the window’s apparent type.

pub fn setAnimationBehavior( &self, animation_behavior: NSWindowAnimationBehavior, )

Available on crate feature NSResponder only.

Setter for animationBehavior.

pub fn isOnActiveSpace(&self) -> bool

Available on crate feature NSResponder only.

Returns YESif this window is associated with the active space. For visible windows, this API indicates whether the window is currently visible on the active space. For offscreen windows, it indicates whether ordering the window onscreen would make it bring it onto the active space

pub fn toggleFullScreen(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.

-toggleFullScreen: enters or exits for full screen. A window must have NSWindowCollectionBehaviorFullScreenAuxiliaryor NSWindowCollectionBehaviorFullScreenPrimaryincluded in the collectionBehaviorproperty; if it does not, this method may simply do nothing.

pub fn stringWithSavedFrame(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn setFrameFromString(&self, string: &NSString)

Available on crate feature NSResponder only.
pub fn saveFrameUsingName(&self, name: &NSString)

Available on crate feature NSResponder only.
pub fn setFrameUsingName_force(&self, name: &NSString, force: bool) -> bool

Available on crate feature NSResponder only.
pub fn setFrameUsingName(&self, name: &NSString) -> bool

Available on crate feature NSResponder only.
pub fn setFrameAutosaveName(&self, name: &NSString) -> bool

Available on crate feature NSResponder only.
pub fn frameAutosaveName(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn minSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setMinSize(&self, min_size: CGSize)

Available on crate feature NSResponder only.

Setter for minSize.

pub fn maxSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setMaxSize(&self, max_size: CGSize)

Available on crate feature NSResponder only.

Setter for maxSize.

pub fn contentMinSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setContentMinSize(&self, content_min_size: CGSize)

Available on crate feature NSResponder only.

Setter for contentMinSize.

pub fn contentMaxSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setContentMaxSize(&self, content_max_size: CGSize)

Available on crate feature NSResponder only.

Setter for contentMaxSize.

pub fn minFullScreenContentSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setMinFullScreenContentSize(&self, min_full_screen_content_size: CGSize)

Available on crate feature NSResponder only.
pub fn maxFullScreenContentSize(&self) -> CGSize

Available on crate feature NSResponder only.
pub fn setMaxFullScreenContentSize(&self, max_full_screen_content_size: CGSize)

Available on crate feature NSResponder only.
pub fn deviceDescription(&self) -> Retained<NSDictionary<NSString>>

Available on crate features NSGraphics and NSResponder only.
pub fn endSheet(&self, sheet_window: &NSWindow)

Available on crate feature NSResponder only.
pub fn sheets(&self) -> Retained<NSArray<NSWindow>>

Available on crate feature NSResponder only.

An ordered array of the sheets on the window. This consists of the presented sheets in top-to-bottom order, followed by queued sheets in the order they were queued. This does not include nested/sub-sheets.

pub fn attachedSheet(&self) -> Option<Retained<NSWindow>>

Available on crate feature NSResponder only.

Returns the top-most sheet if there is one or more sheets, or nil if there is no sheet.

pub fn isSheet(&self) -> bool

Available on crate feature NSResponder only.
pub fn sheetParent(&self) -> Option<Retained<NSWindow>>

Available on crate feature NSResponder only.

Returns the window that the sheet is directly attached to. This is based on the logical attachment of the sheet, not visual attachment. This relationship exists starting when the sheet is begun (using NSApplication's``-beginSheet:modalForWindow:modalDelegate:didEndSelector:contextInfo: or NSWindow's -beginSheet:completionHandler:), and ending once it is ordered out. Returns nil if the window is not a sheet or has no sheet parent.

pub unsafe fn addChildWindow_ordered( &self, child_win: &NSWindow, place: NSWindowOrderingMode, )

Available on crate features NSGraphics and NSResponder only.
pub fn removeChildWindow(&self, child_win: &NSWindow)

Available on crate feature NSResponder only.
pub fn childWindows(&self) -> Option<Retained<NSArray<NSWindow>>>

Available on crate feature NSResponder only.
pub fn parentWindow(&self) -> Option<Retained<NSWindow>>

Available on crate feature NSResponder only.
pub unsafe fn setParentWindow(&self, parent_window: Option<&NSWindow>)

Available on crate feature NSResponder only.

Setter for parentWindow.

This is a weak property.

pub fn appearanceSource(&self) -> Option<Retained<NSObject>>

Available on crate features NSAppearance and NSResponder only.

If set, the receiver will inherit the appearance of that object, as well as use KVO to observe its effectiveAppearance for changes. Typically this is used for child windows that are shown from a parent window or specific view. Defaults to NSApp.

pub unsafe fn setAppearanceSource(&self, appearance_source: Option<&NSObject>)

Available on crate features NSAppearance and NSResponder only.

Setter for appearanceSource.

This is a weak property.

Safety
  • appearance_source must implement NSAppearanceCustomization.
  • appearance_source might not allow None.
pub fn canRepresentDisplayGamut(&self, display_gamut: NSDisplayGamut) -> bool

Available on crate features NSGraphics and NSResponder only.

-canRepresentDisplayGamut: returns YESif the colorSpace of the receiving window, and the colorSpaceof the screen containing that window, are capable of representing the given display gamut

pub fn occlusionState(&self) -> NSWindowOcclusionState

Available on crate feature NSResponder only.
pub fn titlebarSeparatorStyle(&self) -> NSTitlebarSeparatorStyle

Available on crate feature NSResponder only.

Specifies the style of separator displayed between the window’s titlebar and content.

The default value is NSTitlebarSeparatorStyleAutomatic. Changing this value will override any preference made by NSSplitViewItem.

pub fn setTitlebarSeparatorStyle( &self, titlebar_separator_style: NSTitlebarSeparatorStyle, )

Available on crate feature NSResponder only.
pub fn contentViewController(&self) -> Option<Retained<NSViewController>>

Available on crate features NSResponder and NSViewController only.

The main content view controller for the window. This provides the contentView of the window. Assigning this value will remove the existing contentView and will make the contentViewController.view the main contentView for the window. The default value is nil. The contentViewController only controls the contentView, and not the title of the window. The window title can easily be bound to the contentViewController with the following: [window bind:NSTitleBinding toObject:contentViewController withKeyPath: “ title“ options:nil]. Setting the contentViewController will cause the window to resize based on the current size of the contentViewController. Autolayout should be used to restrict the size of the window. The value of the contentViewController is encoded in the NIB. Directly assigning a contentView will clear out the contentViewController.

pub fn setContentViewController( &self, content_view_controller: Option<&NSViewController>, )

Available on crate features NSResponder and NSViewController only.
pub fn initialFirstResponder(&self) -> Option<Retained<NSView>>

Available on crate features NSResponder and NSView only.
pub fn setInitialFirstResponder(&self, initial_first_responder: Option<&NSView>)

Available on crate features NSResponder and NSView only.

Setter for initialFirstResponder.

This is a weak property.

pub fn selectNextKeyView(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn selectPreviousKeyView(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn selectKeyViewFollowingView(&self, view: &NSView)

Available on crate features NSResponder and NSView only.
pub fn selectKeyViewPrecedingView(&self, view: &NSView)

Available on crate features NSResponder and NSView only.
pub fn keyViewSelectionDirection(&self) -> NSSelectionDirection

Available on crate feature NSResponder only.
pub fn disableKeyEquivalentForDefaultButtonCell(&self)

Available on crate feature NSResponder only.
pub fn enableKeyEquivalentForDefaultButtonCell(&self)

Available on crate feature NSResponder only.
pub fn autorecalculatesKeyViewLoop(&self) -> bool

Available on crate feature NSResponder only.
pub fn setAutorecalculatesKeyViewLoop( &self, autorecalculates_key_view_loop: bool, )

Available on crate feature NSResponder only.
pub fn recalculateKeyViewLoop(&self)

Available on crate feature NSResponder only.
pub fn toggleToolbarShown(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn runToolbarCustomizationPalette(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn showsToolbarButton(&self) -> bool

👎Deprecated:

This property has no effect

Available on crate feature NSResponder only.
pub fn setShowsToolbarButton(&self, shows_toolbar_button: bool)

👎Deprecated:

This property has no effect

Available on crate feature NSResponder only.

Setter for showsToolbarButton.

pub fn tabbingMode(&self) -> NSWindowTabbingMode

Available on crate feature NSResponder only.

Get and set the tabbing mode for this window. This should be set before a window is shown. The default value is NSWindowTabbingModeAutomatic.When the value is NSWindowTabbingModeAutomatic,the system will look at the userTabbingPreferenceand automatically tab windows together based on the tabbingIdentifier, when it is appropriate to do so.

pub fn setTabbingMode(&self, tabbing_mode: NSWindowTabbingMode)

Available on crate feature NSResponder only.

Setter for tabbingMode.

pub fn tabbingIdentifier(&self) -> Retained<NSString>

Available on crate feature NSResponder only.

Windows with the same tabbingIdentifierwill have the ability to be tabbed together when a window is being shown. This allows aggregation of similar windows. By default, the tabbingIdentifierwill be generated based on inherent window properties, such as the window class name, the delegate class name, the window controller class name, and some additional state. Windows can be explicitly made to group together by using the same tabbingIdentifier.

pub fn setTabbingIdentifier(&self, tabbing_identifier: &NSString)

Available on crate feature NSResponder only.

Setter for tabbingIdentifier.

This is copied when set.

pub fn selectNextTab(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.

Actions that can be called to perform various tabbed window behaviors. UI that is hooked up to these items can be automatically validated by calling NSWindow’s validateUserInterfaceItem.

pub fn selectPreviousTab(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn moveTabToNewWindow(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn mergeAllWindows(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn toggleTabBar(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub fn toggleTabOverview(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.

Toggle the Tab Picker / Tab Overview UI which is invoked via “Show All Tabs”. Performs the toggle in an animated fashion. Use tabGroup.isOverviewVisible to find out if it is visible or not at a given time.

pub fn tabbedWindows(&self) -> Option<Retained<NSArray<NSWindow>>>

Available on crate feature NSResponder only.

This is now a cover for self.tabGroup.windows, but will return nil if the window is not showing a tab bar.

pub fn addTabbedWindow_ordered( &self, window: &NSWindow, ordered: NSWindowOrderingMode, )

Available on crate features NSGraphics and NSResponder only.

This is now a cover for -[self.tabGroup addWindow:], which allows more precise placement.

pub fn hasActiveWindowSharingSession(&self) -> bool

Available on crate feature NSResponder only.

Indicates whether the receiver is the subject of an active SharePlay sharing session.

pub fn acceptsMouseMovedEvents(&self) -> bool

Available on crate feature NSResponder only.
pub fn setAcceptsMouseMovedEvents(&self, accepts_mouse_moved_events: bool)

Available on crate feature NSResponder only.
pub fn ignoresMouseEvents(&self) -> bool

Available on crate feature NSResponder only.
pub fn setIgnoresMouseEvents(&self, ignores_mouse_events: bool)

Available on crate feature NSResponder only.

Setter for ignoresMouseEvents.

pub fn mouseLocationOutsideOfEventStream(&self) -> CGPoint

Available on crate feature NSResponder only.
pub fn disableCursorRects(&self)

Available on crate feature NSResponder only.
pub fn enableCursorRects(&self)

Available on crate feature NSResponder only.
pub fn discardCursorRects(&self)

Available on crate feature NSResponder only.
pub fn areCursorRectsEnabled(&self) -> bool

Available on crate feature NSResponder only.
pub fn invalidateCursorRectsForView(&self, view: &NSView)

Available on crate features NSResponder and NSView only.
pub fn resetCursorRects(&self)

Available on crate feature NSResponder only.
pub fn unregisterDraggedTypes(&self)

Available on crate feature NSResponder only.
pub fn cacheImageInRect(&self, rect: CGRect)

👎Deprecated:

This method shouldn’t be used as it doesn’t work in all drawing situations; instead, a subview should be used that implements the desired drawing behavior

Available on crate feature NSResponder only.
pub fn restoreCachedImage(&self)

👎Deprecated:

This method shouldn’t be used as it doesn’t work in all drawing situations; instead, a subview should be used that implements the desired drawing behavior

Available on crate feature NSResponder only.
pub fn discardCachedImage(&self)

👎Deprecated:

This method shouldn’t be used as it doesn’t work in all drawing situations; instead, a subview should be used that implements the desired drawing behavior

Available on crate feature NSResponder only.
pub fn gState(&self) -> isize

👎Deprecated:

This method is unused and should not be called.

Available on crate feature NSResponder only.
pub fn convertBaseToScreen(&self, point: CGPoint) -> CGPoint

👎Deprecated:

Use -convertRectToScreen: or -convertPointToScreen: instead

Available on crate feature NSResponder only.
pub fn convertScreenToBase(&self, point: CGPoint) -> CGPoint

👎Deprecated:

Use -convertRectFromScreen or -convertPointFromScreen: instead

Available on crate feature NSResponder only.
pub fn useOptimizedDrawing(&self, flag: bool)

👎Deprecated:

This method does not do anything and should not be called.

Available on crate feature NSResponder only.
pub fn canStoreColor(&self) -> bool

👎Deprecated:

This method does not do anything and should not be called.

Available on crate feature NSResponder only.
pub fn disableFlushWindow(&self)

👎Deprecated:

Use +[NSAnimationContext runAnimationGroup:completionHandler:] to perform atomic updates across runloop invocations.

Available on crate feature NSResponder only.
pub fn enableFlushWindow(&self)

👎Deprecated:

Use +[NSAnimationContext runAnimationGroup:completionHandler:] to perform atomic updates across runloop invocations.

Available on crate feature NSResponder only.
pub fn isFlushWindowDisabled(&self) -> bool

👎Deprecated:

Use +[NSAnimationContext runAnimationGroup:completionHandler:] to perform atomic updates across runloop invocations.

Available on crate feature NSResponder only.
pub fn flushWindow(&self)

👎Deprecated:

Allow AppKit’s automatic deferred display mechanism to take care of flushing any graphics contexts as needed.

Available on crate feature NSResponder only.
pub fn flushWindowIfNeeded(&self)

👎Deprecated:

Allow AppKit’s automatic deferred display mechanism to take care of flushing any graphics contexts as needed.

Available on crate feature NSResponder only.
pub fn isAutodisplay(&self) -> bool

👎Deprecated:

Use +[NSAnimationContext runAnimationGroup:completionHandler:] to temporarily prevent AppKit’s automatic deferred display mechanism from drawing.

Available on crate feature NSResponder only.
pub fn setAutodisplay(&self, autodisplay: bool)

👎Deprecated:

Use +[NSAnimationContext runAnimationGroup:completionHandler:] to temporarily prevent AppKit’s automatic deferred display mechanism from drawing.

Available on crate feature NSResponder only.

Setter for isAutodisplay.

pub fn isOneShot(&self) -> bool

👎Deprecated:

This property does not do anything and should not be used

Available on crate feature NSResponder only.
pub fn setOneShot(&self, one_shot: bool)

👎Deprecated:

This property does not do anything and should not be used

Available on crate feature NSResponder only.

Setter for isOneShot.

pub fn preferredBackingLocation(&self) -> NSWindowBackingLocation

👎Deprecated:

This property does not do anything and should not be used

Available on crate feature NSResponder only.
pub fn setPreferredBackingLocation( &self, preferred_backing_location: NSWindowBackingLocation, )

👎Deprecated:

This property does not do anything and should not be used

Available on crate feature NSResponder only.
pub fn backingLocation(&self) -> NSWindowBackingLocation

👎Deprecated:

This property does not do anything and should not be used

Available on crate feature NSResponder only.
pub fn showsResizeIndicator(&self) -> bool

👎Deprecated:

This property does not do anything and should not be used.

Available on crate feature NSResponder only.
pub fn setShowsResizeIndicator(&self, shows_resize_indicator: bool)

👎Deprecated:

This property does not do anything and should not be used.

Available on crate feature NSResponder only.
pub fn windowRef(&self) -> NonNull<c_void>

👎Deprecated:

This method should not be used.

Available on crate feature NSResponder only.
pub fn disableScreenUpdatesUntilFlush(&self)

👎Deprecated:

This method does not do anything and should not be called.

Available on crate feature NSResponder only.

Methods from Deref<Target = NSResponder>

pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>

Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)

Setter for nextResponder.

Safety

This is unretained, you must ensure the object is kept alive while in use.

pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool

Safety
  • action must be a valid selector.
  • object should be of the correct type.
pub unsafe fn noResponderFor(&self, event_selector: Sel)

Safety

event_selector must be a valid selector.

pub fn acceptsFirstResponder(&self) -> bool

pub fn becomeFirstResponder(&self) -> bool

pub fn resignFirstResponder(&self) -> bool

pub fn flushBufferedKeyEvents(&self)

pub fn menu(&self) -> Option<Retained<NSMenu>>

Available on crate feature NSMenu only.
pub unsafe fn setMenu(&self, menu: Option<&NSMenu>)

Available on crate feature NSMenu only.

Setter for menu.

pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub unsafe fn presentError_modalForWindow_delegate_didPresentSelector_contextInfo( &self, error: &NSError, window: &NSWindow, delegate: Option<&AnyObject>, did_present_selector: Option<Sel>, context_info: *mut c_void, )

Available on crate feature NSWindow only.
Safety
  • delegate should be of the correct type.
  • did_present_selector must be a valid selector.
  • context_info must be a valid pointer or null.
pub fn presentError(&self, error: &NSError) -> bool

pub fn willPresentError(&self, error: &NSError) -> Retained<NSError>

pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated:

This has always returned NO and had no effect on macOS

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}